%global gdeploymod ansible/modules/gdeploy
%define release 10
%define gdeploytemp /usr/share/gdeploy
%define gdeploydoc /usr/share/doc/gdeploy

Name:           gdeploy
Version:        3.0.0
Release:        %{release}%{?dist}
Summary:        Tool to deploy and manage GlusterFS cluster

License:        GPLv3+
URL:            https://github.com/gluster/gdeploy
Source0:        %{name}-%{version}-%{release}.tar.gz
BuildArch:      noarch
Requires:       python3-pyyaml > 3 
Requires:       ansible-core >= 2.12
Requires:       python3
Requires:       lvm2

BuildRequires:  python3-setuptools
BuildRequires:  python3-devel

%description
gdeploy is an Ansible based deployment tool. Initially gdeploy was written to
install GlusterFS clusters, eventually it grew out to do lot of other things. On
a given set of hosts, gdeploy can create physical volumes, volume groups, and
logical volumes, install packages, subscribe to RHN channels, run shell
commands, create GlusterFS volumes and more.

See http://gdeploy.readthedocs.io/en/latest/ for more details

%prep
%setup -q -n %{name}-%{version}-%{release}

%build
%py3_build
pushd docs
make html
popd

%install
# Install the binary and python3 libraries
%py3_install

mkdir -p %{buildroot}/%{python3_sitelib}/%{gdeploymod}
install -p -m 755 modules/* \
    %{buildroot}/%{python3_sitelib}/%{gdeploymod}

# Install the playbooks into /usr/share/gdeploy/playbooks
mkdir -p %{buildroot}/%{gdeploytemp}
cp -rp playbooks %{buildroot}/%{gdeploytemp}

# Install scripts
cp -rp extras/scripts %{buildroot}/%{gdeploytemp}

# Install usecases
cp -rp extras/usecases %{buildroot}/%{gdeploytemp}

# Install the script to /usr/bin
mkdir -p %{buildroot}/usr/bin
install -p -m 755 extras/usecases/replace-node/gluster-replace-node \
        %{buildroot}/usr/bin

# Install the gdeploy plugin
mkdir -p %{buildroot}/%{python3_sitelib}/ansible/plugins/callback
install -p -m 755 plugins/callback/gdeploy.py \
        %{buildroot}/%{python3_sitelib}/ansible/plugins/callback/

# Documentation
mkdir -p %{buildroot}/%{gdeploydoc} %{buildroot}/%{_mandir}/man1/ \
	 %{buildroot}/%{_mandir}/man5/
cp -rp docs/* README.md examples %{buildroot}/%{gdeploydoc}
cp man/gdeploy.1* %{buildroot}/%{_mandir}/man1/
cp man/gdeploy.conf* %{buildroot}/%{_mandir}/man5/

# Man pages
mkdir -p %{buildroot}/%{_mandir}/man1/ \
       %{buildroot}/%{_mandir}/man5/
cp -p man/gdeploy.1* %{buildroot}/%{_mandir}/man1/
cp -p man/gdeploy.conf* %{buildroot}/%{_mandir}/man5/

%files
%{_bindir}/gdeploy
%{python3_sitelib}/gdeploy*
%{gdeploytemp}
%{python3_sitelib}/%{gdeploymod}
%{_bindir}/gluster-replace-node
%{python3_sitelib}/ansible/plugins/callback/gdeploy.py*
%{python3_sitelib}/ansible/plugins/callback/*

%doc README.md TODO
%license LICENSE
%{_mandir}/man1/gdeploy*
%{_mandir}/man5/gdeploy*

%docdir %{gdeploydoc}
%{gdeploydoc}

%package doc
Summary: gdeploy documentation
BuildRequires:  python3-sphinx

%description doc
gdeploy is an Ansible based deployment tool, used to deploy and configure
GlusteFS.

gdeploy-doc package provides the documentation for writing gdeploy
configuration files to deploy and configure GlusterFS.

%files doc
%doc %{_pkgdocdir}

%changelog
* Wed May 04 2022 Goinda Das <godas@redhat.com> 3.0.0-10
- Building gdeploy3.0.0 for RHEL8 ,making compartible with ansible-core rhbz#2068482

* Mon May 02 2022 Goinda Das <godas@redhat.com> 3.0.0-9
- Building gdeploy3.0.0 for RHEL8 ,making compartible with ansible-core rhbz#2068482

* Thu Jul 16 2020 Prajith Kesava Prasad <pkesavap@redhat.com> 3.0.0-8
- Removed the task of disabling network service rhbz#1845042

* Mon May 4 2020 Prajith Kesava Prasad <pkesavap@redhat.com> 3.0.0-7
- Resolves stopping of nfs ,service, only if exists issue rhbz#1826804

* Mon Apr 13 2020 Prajith Kesava Prasad <pkesavap@redhat.com> 3.0.0-6
- Resolves selinux relabelling issue rhbz#1820728 and invalid selinux context issue rhbz#1821907

* Fri Apr 3 2020 Prajith Kesava Prasad <pkesavap@redhat.com> 3.0.0-5
- Building gdeploy3.0.0 for RHEL8 , fixing pcs issue in nfs_ganesha, rhbz#1813908

* Fri Mar 20 2020 Prajith Kesava Prasad <pkesavap@redhat.com> 3.0.0-4
- Building gdeploy3.0.0 for RHEL8 , fixing nfs_ganesha setup failing, rhbz#1813166

* Wed Mar 04 2020 Prajith Kesava Prasad <pkesavap@redhat.com> 3.0.0-3
- Building gdeploy3.0.0 for RHEL8 ,fixing multiple vg creation issue rhbz#1805164

* Mon Feb 10 2020 Prajith Kesava Prasad <pkesavap@redhat.com> 3.0.0-2
- Building gdeploy for RHEL8 by removing vdo related changes rhbz#1799005

* Wed Jan 22 2020 Prajith Kesava Prasad <pkesavap@redhat.com> 3.0.0-1
- Building gdeploy for RHGS3.5 upon RHEL8 rhbz#1793959

* Mon Oct 14 2019 Sachidananda Urs <sac@redhat.com> 2.0.2-35
- Set group and user.cifs volume options for SMB rhbz#1759810

* Tue Jun 18 2019 Sachidananda Urs <sac@redhat.com> 2.0.2-34
- Create samba user on all nodes rhbz#1712904

* Fri May 17 2019 Sachidananda Urs <sac@redhat.com> 2.0.2-33
- Set shared-storage and meta-volume options for georep rhbz#1707704

* Fri Feb 08 2019 Sachidananda Urs <sac@redhat.com> 2.0.2-32
- Handle different locales gracefully. Resolves: bz#1662068

* Mon Dec 03 2018 Sachidananda Urs <sac@redhat.com> 2.0.2-31
- Set mount options appropriately for vdo disks.
- Resolves bz#1654584 bz#1649509

* Mon Oct 15 2018 Sachidananda Urs <sac@redhat.com> 2.0.2-30
- Do not update XFS runtime config. Resolves bz#1638623

* Thu Oct 04 2018 Sachidananda Urs <sac@redhat.com> 2.0.2-29
- Do not check for diskcount in case of JBODs in backend-setup

* Mon Sep 24 2018 Sachidananda Urs <sac@redhat.com> 2.0.2-28
- Do not check for diskcount in case of JBODs

* Tue May 22 2018 Devyani Kota <dkota@redhat.com> 2.0.2-27
- Fix fstab entries and allow multiple slabsize for VDO

* Fri Apr 20 2018 Devyani Kota <dkota@redhat.com> 2.0.2-26
- Add checks for ganesha and subscription errors and VDO fixes

* Mon Apr 16 2018 Devyani Kota <dkota@redhat.com> 2.0.2-25
- Remove VDO module and XFS metadata fixes

* Tue Apr 03 2018 Devyani Kota <dkota@redhat.com> 2.0.2-24
- XFS ENOSPC and EIO metadata fixes

* Wed Mar 21 2018 Devyani Kota <dkota@redhat.com> 2.0.2-23
- Geo-replication fixes and CPUQuota fixes

* Wed Dec 27 2017 Devyani Kota <dkota@redhat.com> 2.0.2-22
- Ctdb and regex pattern fixes

* Fri Nov 24 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-21
- Added vdo feature

* Tue Nov 14 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-20
- Add geo-replication feature

* Sun Nov 5 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-19
- Remove the multiple display support, broken in Ansible-2.4

* Thu Oct 26 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-18
- Do not load `multipath', dm_multipath should be enough

* Mon Oct 16 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-17
- Load multipath module before calling multipath -F

* Fri Sep 22 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-16
- Fix the lvchange issue, --zero should always be `n'

* Thu Sep 7 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-15
- Change the permissions of file glusterfs.ca to world readable

* Fri Jul 28 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-14
- Restore the disable-multipath.sh script for backward compat

* Wed Jul 19 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-13
- Copy the extras/scripts into /usr/share/ansible/gdeploy
- This a compatibility fix for cockpit plugin, should be removed
- in next major/minor version of gdeploy

* Tue Jun 27 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-12
- Do not throw `volume start failed' error if volume is already started
- Add service `glusterfssharedstorage' to NFS Ganesha pre-requisites
- Add service `nfs-ganesha' to NFS Ganesha pre-requisites

* Thu Jun 22 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-11
- Updated extras/scripts to enable multipath

* Thu May 18 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-10
- Use shell module instead of script while executing a script

* Tue May 16 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-9
- Print the status of add-node command

* Mon May 15 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-8
- Do not export a volume unless specified in [nfs-ganesha] section

* Thu May 11 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-7
- Move the modues to ansible/modules from ansible/modules/extras

* Fri May 5 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-6
- Fixes a traceback caused for accessing non-existent key

* Fri May 5 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-5
- Fixes bugs: 1447271 1446509 1446092 1444829

* Tue Apr 25 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-4
- Add cachesize variable to [backend-setup] section

* Thu Apr 13 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-3
- Fix a traceback in RHEL6, catch exception and print message

* Thu Mar 30 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-2
- Fixed an issue where playbooks were installed wrongly

* Wed Mar 22 2017 Sachidananda Urs <sac@redhat.com> 2.0.2-1
- Fixes NFS Ganesha delete node issue
- Add support for RAID5

* Wed Feb 15 2017 Sachidananda Urs <sac@redhat.com> 2.0.1-11
- Fixes bugs: 1405447, 1418903
- Fixes ganesha add node issues and sanity check script

* Sun Feb 12 2017 Sachidananda Urs <sac@redhat.com> 2.0.1-10
- Fixes bugs: 1419932, 1418903
- Fixes an issue where chunksize was computed wrongly

* Thu Feb 02 2017 Sachidananda Urs <sac@redhat.com> 2.0.1-9
- Fixes bugs: 1405447, 1409861, 1411259, 1411658, 1416361

* Thu Dec 22 2016 Sachidananda Urs <sac@redhat.com> 2.0.1-8
- Fixes bug: 1341484, Fix the lv playbook; remove ignore_errors flag

* Fri Dec 16 2016 Sachidananda Urs <sac@redhat.com> 2.0.1-7
- Fixes bug: 1341484, Fix the playbooks to honour ignore_errors flag

* Tue Dec 6 2016 Sachidananda Urs <sac@redhat.com> 2.0.1-6
- Fixes bug: 1393966, fixes the console message reporting

* Tue Nov 22 2016 Sachidananda Urs <sac@redhat.com> 2.0.1-5
- Fixes bugs: 1368096, 1396008

* Wed Nov 16 2016 Sachidananda Urs <sac@redhat.com> 2.0.1-4
- Fixes bugs: 1394636, 1393970, 1393968, 1394636

* Wed Nov 2 2016 Sachidananda Urs <sac@redhat.com> 2.0.1-3
- Fixes bugs: 1390872, 1390871, 1387174

* Thu Sep 29 2016 Sachidananda Urs <sac@redhat.com> 2.0.1-2
- Fixes bug: 1348090

* Thu Sep 15 2016 Sachidananda Urs <sac@redhat.com> 2.0.1-1
- Add support for configuring NFS Ganesha, Samba, and CTDB

* Thu May 19 2016 Sachidananda Urs <sac@redhat.com> 2.0-16
- Fixes bug: 1335428, use the complete path for repo names

* Tue May 17 2016 Sachidananda Urs <sac@redhat.com> 2.0-15
- Fixes bug: 1335428, added UUID for repo names.

* Fri May 13 2016 Sachidananda Urs <sac@redhat.com> 2.0-14
- Fixes bug: 1335428, duplicate repos.

* Fri May 13 2016 Sachidananda Urs <sac@redhat.com> 2.0-13
- Fixes bugs: 1330026, 1334705, 1330426 - Resolved a conflict.

* Fri May 13 2016 Sachidananda Urs <sac@redhat.com> 2.0-12
* Fixes bugs: 1330026, 1334705, 1330426

* Fri May 6 2016 Sachidananda Urs <sac@redhat.com> 2.0-11
- Fixes bug: 1330026, removed rdma and `force' in volume creation

* Thu May 5 2016 Sachidananda Urs <sac@redhat.com> 2.0-10
- Fixes bug: 1330026, re-ordered sections for hc setup

* Thu May 5 2016 Sachidananda Urs <sac@redhat.com> 2.0-9
- Fixes bug: 1330026

* Wed Apr 27 2016 Sachidananda Urs <sac@redhat.com> 2.0-8
- Fixes bugs: 1328856, 1329903, 1330426
  Rebuilt on top of 2.0-7 to fix a minor json typo

* Wed Apr 27 2016 Sachidananda Urs <sac@redhat.com> 2.0-7
- Fixes bugs: 1328856, 1329903, 1330426

* Thu Apr 21 2016 Sachidananda Urs <sac@redhat.com> 2.0-6
- LV related fixes; fixes bug: 1329070

* Mon Apr 11 2016 Sachidananda Urs <sac@redhat.com> 2.0-5
- VG related fixes

* Mon Apr 11 2016 Sachidananda Urs <sac@redhat.com> 2.0-4
- Client mount related fixes

* Mon Apr 11 2016 Sachidananda Urs <sac@redhat.com> 2.0-3
- New LV, VG, and PV modules to accomodate hyperconvergence
  requirements.

* Mon Mar 21 2016 Sachidananda Urs <sac@redhat.com> 2.0-2
- Rebase from 1.0 branch with lots of new features:
- New and intuitive config file layout.
- Multiple volume support
- Backend-reset support
- Quota support

* Wed Dec 30 2015 Sachidananda Urs <sac@redhat.com> 1.1-4
- Added more documentation

* Tue Dec 8 2015 Sachidananda Urs <sac@redhat.com> 1.1-3
- Added support for NFS-Ganesha

* Mon Nov 9 2015 Sachidananda Urs <sac@redhat.com> 1.1-2
- Bump the version of gdeploy

* Fri Nov 6 2015 Sachidananda Urs <sac@redhat.com> 1.1
- Added new features: Quota, snapshot, geo-rep, and
- HyperConvergence related features.

* Wed Sep 16 2015 Sachidananda Urs <sac@redhat.com> 1.0-12
- Blocker bug fixes

* Fri Sep 11 2015 Sachidananda Urs <sac@redhat.com> 1.0-11
- Fixes bugs #1261881 #1257162

* Wed Sep 9 2015 Sachidananda Urs <sac@redhat.com> 1.0-10
- Fixes security bugs #1260614 #1260709

* Mon Sep 7 2015 Sachidananda Urs <sac@redhat.com> 1.0-9
- Fixes bugs #1260597, #1260614, #1260709

* Thu Sep 3 2015 Sachidananda Urs <sac@redhat.com> 1.0-8
- Fixes bugs #1248899, #1253344, #1254941

* Mon Aug 31 2015 Sachidananda Urs <sac@redhat.com> 1.0-7
- Bug fixes

* Tue Aug 25 2015 Sachidananda Urs <sac@redhat.com> 1.0-6
- Fix the release naming in the tar.gz

* Thu Aug 20 2015 Sachidananda Urs <sac@redhat.com> 1.0-3
- Fix build issues related to RHEL 6.7

* Thu Aug 20 2015 Sachidananda Urs <sac@redhat.com> 1.0-2
- Spec file fixes, included BuildRequires

* Thu Aug 20 2015 Sachidananda Urs <sac@redhat.com> 1.0-1
- Spec file fixes

* Mon Aug 3 2015 Sachidananda Urs <sac@redhat.com> 1.0
- Initial release.
